Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(23)

Unified Diff: chrome/browser/extensions/extension_creator_filter.h

Issue 12163003: Add FilePath to base namespace. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/extensions/extension_creator_filter.h
diff --git a/chrome/browser/extensions/extension_creator_filter.h b/chrome/browser/extensions/extension_creator_filter.h
index c13e2c261b387b07acaf36b11bd7b81b218a16d8..6c0aac6d2b9e1ddfe35f84691ce0196d0bec09ad 100644
--- a/chrome/browser/extensions/extension_creator_filter.h
+++ b/chrome/browser/extensions/extension_creator_filter.h
@@ -7,7 +7,9 @@
#include "base/memory/ref_counted.h"
+namespace base {
class FilePath;
+}
namespace extensions {
@@ -18,9 +20,9 @@ class ExtensionCreatorFilter
public:
ExtensionCreatorFilter() {}
// Returns true if the given FilePath should be included in a
// packed extension.
- bool ShouldPackageFile(const FilePath& file_path);
+ bool ShouldPackageFile(const base::FilePath& file_path);
private:
friend class base::RefCounted<ExtensionCreatorFilter>;
« no previous file with comments | « chrome/browser/extensions/extension_creator.h ('k') | chrome/browser/extensions/external_provider_interface.h » ('j') | no next file with comments »
@@ -18,9 +20,9 @@ class ExtensionCreatorFilter
public:
ExtensionCreatorFilter() {}
- // Returns true if the given FilePath should be included in a
+ // Returns true if the given base::FilePath should be included in a
// packed extension.

Powered by Google App Engine
This is Rietveld 408576698